==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.openexchange.freebusy/src/com/openexchange/freebusy/FreeBusyExceptionMessages.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.freebusy;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link FreeBusyExceptionMessages}
 *
 * Translatable messages for {@link FreeBusyExceptionCodes}.
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public final class FreeBusyExceptionMessages implements LocalizableStrings {

    public static final String NO_PROVIDERS_AVAILABLE_MSG = "No free/busy providers available";
    public static final String AMBIGUOUS_PARTICIPANT_MSG = "The participant \"%1$s\" is ambiguous.";
    public static final String PARTICIPANT_NOT_FOUND_MSG = "The participant \"%1$s\" can't be found.";
    public static final String FREEBUSY_NOT_ENABLED_MSG = "Free/busy is not enabled for user %1$d in context %2$d.";
    public static final String DATA_NOT_AVAILABLE_MSG = "Free/busy data for \"%1$s\" is not available.";
    public static final String COMMUNICATION_FAILURE_MSG = "A communication error occured while processing the free/busy request (\"%1$s\").";
    public static final String EXTERNAL_ERROR_MSG = "An external error occured while processing the free/busy request (\"%1$s\").";
    public static final String INTERNAL_ERROR_MSG = "An internal error occured while processing the free/busy request (\"%1$s\").";
    public static final String CONFIGURATION_ERROR_MSG = "A configuration error occured (\"%1$s\").";

    /**
     * Prevent instantiation.
     */
    private FreeBusyExceptionMessages() {
        super();
    }
}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.freebusy/src/com/openexchange/freebusy/FreeBusyExceptionMessages.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.freebusy;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link FreeBusyExceptionMessages}
 *
 * Translatable messages for {@link FreeBusyExceptionCodes}.
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public final class FreeBusyExceptionMessages implements LocalizableStrings {

    public static final String NO_PROVIDERS_AVAILABLE_MSG = "No free/busy providers available";
    public static final String AMBIGUOUS_PARTICIPANT_MSG = "The participant \"%1$s\" is ambiguous.";
    public static final String PARTICIPANT_NOT_FOUND_MSG = "The participant \"%1$s\" can't be found.";
    public static final String FREEBUSY_NOT_ENABLED_MSG = "Free/busy is not enabled for user %1$d";
    public static final String DATA_NOT_AVAILABLE_MSG = "Free/busy data for \"%1$s\" is not available.";

    /**
     * Prevent instantiation.
     */
    private FreeBusyExceptionMessages() {
        super();
    }
}
